==> files-1.2.2-sources.jar: io/lenar/files/UserFile.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 Lenar Badretdinov
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package io.lenar.files;

import io.lenar.files.base.BaseUserFile;
import io.lenar.files.interfaces.EzFile;

import java.io.*;
import java.util.List;

/**
 * Provides the functionality for reading regular files in any location in the file system
 */
public class UserFile extends BaseUserFile implements EzFile  {

    public UserFile(String fullFileName) throws FileNotFoundException {
        super(fullFileName);
    }

    public UserFile(String path, String fileName) throws FileNotFoundException {
        super(path, fileName);
    }

    public List<String> lines() {
        return readLines();
    }

    public String content() {
        return readContent();
    }





}

==> files-1.2.4-sources.jar: io/lenar/files/UserFile.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 Lenar Badretdinov
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package io.lenar.files;

import io.lenar.files.base.BaseUserFile;
import io.lenar.files.interfaces.EzFile;

import java.io.*;
import java.util.List;

/**
 * Provides the functionality for reading regular files in any location in the file system
 */
public class UserFile extends BaseUserFile implements EzFile  {

    public UserFile(String fullFileName) {
        super(fullFileName);
    }

    public UserFile(String path, String fileName) {
        super(path, fileName);
    }

    public List<String> lines() throws IOException {
        return readLines();
    }

    public String content() throws IOException {
        return readContent();
    }

}
